/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.log.parser.api;

/**
 * The constants related to Petals logs.
 * @author Vincent Zurczak - EBM WebSourcing
 */
public interface PetalsLogConstants {

    // The standard log attributes, common to service providers and consumers.

    // TODO: Move these constants in artefacts shared with components and CDK to
    // have only one definition

    /**
     * The ID of the Petals node that logged this entry.
     */
    final String PETALS_NODE = "node";

    /**
     * The date of the logged entry.
     */
    final String DATE = "date";

    /**
     * The logger name of the component that created the log entry.
     */
    final String COMPONENT_LOGGER = "component";

    /**
     * The location of the flow's message content (dumped as a XML file).
     */
    final String DUMP_PATH = "payloadContentDumpFile";

    /**
     * The fault or error message when a step fails.
     */
    final String FAILURE_MESSAGE = "failureMessage";


    // SOAP's specific attributes.

    /**
     * The URL of the web service exposed through Petals.
     */
    final String SOAP_CONSUME_REQUESTED_URL = "requestedURL";

    /**
     * The URL of the invoked web service.
     */
    final String SOAP_PROVIDE_REQUESTED_URL = "requestedURL";


    // Mail's specific attributes.

    /**
     * The scheme of the polled mail box.
     */
    final String MAIL_CONSUME_SCHEME = "scheme";

    /**
     * The host of the polled mail box.
     */
    final String MAIL_CONSUME_HOST = "host";

    /**
     * The port of the polled mail box.
     */
    final String MAIL_CONSUME_PORT = "port";

    /**
     * The user name for the polled mail box.
     */
    final String MAIL_CONSUME_USER = "user";

    /**
     * The polled folder in the mail box.
     */
    final String MAIL_CONSUME_FOLDER = "folder";

    /**
     * The email address which was sent an email.
     */
    final String MAIL_PROVIDE_EMAIL_ADDRESS = "emailAddress";


    // SFTP's specific attributes.

    /**
     * The file name pattern when invoking the GET operations (Get, MGet, GetAsAttachment, etc).
     */
    final String SFTP_PROVIDE_PATTERNS = "patterns";

    /**
     * The working folder on the secured FTP server.
     */
    final String SFTP_PROVIDE_FOLDER = "folder";


    // FTP's specific attributes.

    /**
     * The file name pattern when invoking the GET operations (Get, MGet, GetAsAttachment, etc).
     */
    final String FTP_PROVIDE_PATTERNS = "patterns";

    /**
     * The working folder on the FTP server.
     */
    final String FTP_PROVIDE_FOLDER = "folder";


    // File Transfer's specific attributes.

    /**
     * The absolute file path of the file which is <i>eaten</i> by the component.
     */
    final String FILE_TRANSFER_CONSUME_FILE_PATH = "filePath";

    /**
     * The file name or file pattern.
     */
    final String FILE_TRANSFER_PROVIDE_FILE_NAME = "fileName";

    /**
     * The working directory in the file system.
     */
    final String FILE_TRANSFER_PROVIDE_DIRECTORY = "destDirName";


    // SQL's specific attributes.

    /**
     * The SQL service operation.
     * <p>
     * Currently equivalent to {@link #PROVIDE_FLOW_STEP_OPERATION_NAME}.
     * </p>
     *
     * FIXME: should we deprecate it?
     */
    final String SQL_PROVIDE_OPERATION = "operationSQL";


    // Quartz's specific attributes.

    /**
     * The time at which the Quartz sent a message in Petals.
     */
    final String QUARTZ_CONSUME_EVENT_TIME = "eventTime";


    // Other constants.

    /**
     * A separator used when reading raw log entries.
     */
    final String SEP = "==>";
}
