/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.log.parser.api.model;

/**
 * A flow instance with its tree of flow steps.
 * <p>
 * The root is the flow step which has no parent and which has all the others as descendants.
 * </p>
 *
 * @author Pierre-Yves Gibello - EBM WebSourcing
 */
public class Flow implements Comparable<Flow> {

    private final String flowId;

    private final FlowStep root;

    /**
     * Constructor.
     * 
     * @param flowId
     *            The identifier if the flow instance. Not <code>null</code>.
     * @param root
     *            The root flow step. Not <code>null</code>
     */
    public Flow(final String flowId, final FlowStep root) {
        assert flowId != null;
        assert root != null;
        this.flowId = flowId;
        this.root = root;
    }

    /**
     * @return the root
     */
    public FlowStep getRoot() {
        return this.root;
    }

    /**
     * @return the flowId
     */
    public String getFlowId() {
        return this.flowId;
    }

    @Override
    public String toString() {
        return this.root == null ? "null" : this.root.toString(new StringBuilder(), 0);
    }

    @Override
    public int compareTo(final Flow anotherFlow) {
        return this.flowId.compareTo(anotherFlow.getFlowId());
    }

    @Override
    public int hashCode() {
        assert this.flowId != null;

        return 31 + this.flowId.hashCode();
    }

    @Override
    public boolean equals(final Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        final Flow other = (Flow) obj;
        assert this.flowId != null;
        assert other.flowId != null;
        return this.flowId.equals(other.flowId);
    }
}
