/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.log.parser.api;

import java.util.HashMap;

import org.junit.Assert;
import org.junit.Test;
import org.ow2.petals.log.parser.api.model.FlowStep;

/**
 * @author Vincent Zurczak - EBM WebSourcing
 */
public class PetalsLogUtilsTestCase {

    /**
     * Tests {@link PetalsLogUtils#isFlowStepComplete(org.ow2.petals.log.api.model.FlowStep)}.
     * @throws Exception
     */
    @Test
    public void testIsFlowStepComplete() throws Exception {

        // Test a normal flow
        FlowStep flowStep = new FlowStep( "test" );
        flowStep.setType(FlowStep.CONSUME_FLOW_STEP);
        flowStep.setBeginProperties(new HashMap<String,String> ());
        Assert.assertFalse( PetalsLogUtils.isFlowStepComplete( flowStep ));
        
        flowStep.setOutcomeProperties(new HashMap<String,String> ());
        Assert.assertTrue( PetalsLogUtils.isFlowStepComplete( flowStep ));

        // Test an error flow
        flowStep = new FlowStep( "test" );
        flowStep.setType(FlowStep.CONSUME_FLOW_STEP);
        flowStep.setBeginProperties(new HashMap<String,String> ());
        Assert.assertFalse( PetalsLogUtils.isFlowStepComplete( flowStep ));

        flowStep.setOutcomeProperties(new HashMap<String,String> ());
        flowStep.setFailure(true);
        Assert.assertTrue( PetalsLogUtils.isFlowStepComplete( flowStep ));
    }
}
