/**
 * Copyright (c) 2012 EBM WebSourcing, 2012-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.log.parser.api.miscellaneous;

import java.io.File;
import java.io.FileFilter;
import java.io.IOException;
import java.net.URISyntaxException;
import java.net.URL;

import org.junit.Assert;
import org.junit.Ignore;

/**
 * Some utilities for the tests.
 * @author Vincent Zurczak - EBM WebSourcing
 */
@Ignore
public class TestUtils {

    /**
     * Finds the log directories in a sub-directory of "src/test/resources".
     * @param testCaseName the name of the sub-directory into which log directories must be searched
     * @return a non-null and non-empty array of directory files
     * @throws IOException if the sub-directory does not exist
     * @throws URISyntaxException if the developer made a mistake
     */
    public static File[] findTestDirectories( String testCaseName ) throws IOException, URISyntaxException {

        URL url = TestUtils.class.getResource( "/" + testCaseName );
        if( url == null )
            throw new IOException( testCaseName + " is not a valid test directory." );

        File rootFile =  new File( url.toURI());
        Assert.assertTrue( rootFile.isDirectory());

        FileFilter filterDirs = new FileFilter() {
            @Override
            public boolean accept(File file) {
                return file.isDirectory();
            }
        };

        File[] result = rootFile.listFiles( filterDirs );
        Assert.assertNotNull( result );
        Assert.assertTrue( result.length != 0 );

        return result;
    }
}
